#
# Conditional build:
%bcond_with	elogind		# elogind support (instead of systemd)
%bcond_without	systemd		# systemd support
%bcond_without	static_libs	# static library

%if %{with elogind}
%undefine	with_systemd
%endif
Summary:	D-Bus interface for user accounts management
Summary(pl.UTF-8):	Interfejs D-Bus do zarządzania kontami użytkowników
Name:		accountsservice
Version:	0.6.54
Release:	1
License:	GPL v3+
Group:		Applications/System
Source0:	https://www.freedesktop.org/software/accountsservice/%{name}-%{version}.tar.xz
# Source0-md5:	6420f2e619ddcf92230d8f10bad049fe
URL:		https://cgit.freedesktop.org/accountsservice/
BuildRequires:	docbook-dtd412-xml
%{?with_elogind:BuildRequires:	elogind-devel >= 229.4}
BuildRequires:	gettext-tools
BuildRequires:	glib2-devel >= 1:2.44
BuildRequires:	gobject-introspection-devel >= 0.10.0
BuildRequires:	gtk-doc >= 1.15
BuildRequires:	libxslt-progs
BuildRequires:	meson >= 0.46.0
BuildRequires:	ninja
BuildRequires:	pkgconfig
BuildRequires:	polkit-devel >= 0.102
BuildRequires:	rpmbuild(macros) >= 1.641
BuildRequires:	sed >= 4.0
%{?with_systemd:BuildRequires:	systemd-devel >= 1:186}
BuildRequires:	tar >= 1:1.22
BuildRequires:	xmlto
BuildRequires:	xz
Requires(post,preun,postun):	systemd-units >= 1:186
Requires:	%{name}-libs = %{version}-%{release}
Requires:	polkit >= 0.102
Requires:	systemd-units >= 0.38
Suggests:	ConsoleKit
Obsoletes:	accountsservice-systemd
Obsoletes:	vala-accountsservice
BuildRoot:	%{tmpdir}/%{name}-%{version}-root-%(id -u -n)

%description
The AccountsService project provides:
- A set of D-Bus interfaces for querying and manipulating user account
  information.
- An implementation of these interfaces based on the usermod(8),
  useradd(8) and userdel(8) commands.

%description -l pl.UTF-8
Projekt AccountsService dostarcza:
- Zbiór interfejsów D-Bus do odpytywania i manipulowania informacjami
  o kontach użytkowników.
- Implementacje tych interfejsów oparte o komendy usermod(8),
  useradd(8) i userdel(8).

%package libs
Summary:	Shared accountsservice library
Summary(pl.UTF-8):	Biblioteka współdzielona accountsservice
Group:		Libraries
Requires:	glib2 >= 1:2.44
Requires:	systemd-libs >= 1:186
Conflicts:	accountsservice < 0.6.39

%description libs
Shared accountsservice library.

%description libs -l pl.UTF-8
Biblioteka współdzielona accountsservice.

%package devel
Summary:	Development files for accountsservice
Summary(pl.UTF-8):	Pliki programistyczne biblioteki accountsservice
Group:		Development/Libraries
Requires:	%{name}-libs = %{version}-%{release}
Requires:	glib2-devel >= 1:2.44

%description devel
Development files for accountsservice (headers, GObject API, D-Bus
interface description).

%description devel -l pl.UTF-8
Pliki programistyczne biblioteki accountsservice (pliki nagłówkowe,
API GObject, opis interfejsu D-Bus).

%package static
Summary:	accountsservice static library
Summary(pl.UTF-8):	Statyczna biblioteka accountsservice
Group:		Development/Libraries
Requires:	%{name}-devel = %{version}-%{release}

%description static
accountsservice static library.

%description static -l pl.UTF-8
Statyczna biblioteka accountsservice.

%package apidocs
Summary:	API documentation for accountsservice
Summary(pl.UTF-8):	Dokumentacja API accountsservice
Group:		Documentation
Requires:	gtk-doc-common
%if "%{_rpmversion}" >= "5"
BuildArch:	noarch
%endif

%description apidocs
API documentation for accountsservice.

%description apidocs -l pl.UTF-8
Dokumentacja API accountsservice.

%prep
%setup -q

%if %{with static_libs}
%{__sed} -i -e 's/shared_library/library/' src/libaccountsservice/meson.build
%endif

%build
%meson build \
	-Dadmin_group=wheel \
	-Ddocbook=true \
	%{?with_elogind:-Delogind=true} \
	-Dgtk_doc=true \
	%{?with_systemd:-Dsystemd=true} \
	-Dsystemdsystemunitdir=%{systemdunitdir} \

%meson_build -C build

%install
rm -rf $RPM_BUILD_ROOT
install -d $RPM_BUILD_ROOT%{_datadir}/accountsservice/interfaces

%meson_install -C build

%{__rm} $RPM_BUILD_ROOT%{_docdir}/accountsservice/spec/AccountsService.html

%find_lang accounts-service

%clean
rm -rf $RPM_BUILD_ROOT

%post
%systemd_post accounts-daemon.service

%preun
%systemd_preun accounts-daemon.service

%postun
%systemd_reload

%triggerpostun -- accountsservice < 0.6.15-5
%systemd_trigger accounts-daemon.service

%post	libs -p /sbin/ldconfig
%postun	libs -p /sbin/ldconfig

%files -f accounts-service.lang
%defattr(644,root,root,755)
%doc AUTHORS NEWS README.md TODO build/doc/dbus/AccountsService.html
%attr(755,root,root) %{_libexecdir}/accounts-daemon
/etc/dbus-1/system.d/org.freedesktop.Accounts.conf
%{systemdunitdir}/accounts-daemon.service
%dir %{_datadir}/accountsservice
%dir %{_datadir}/accountsservice/interfaces
%{_datadir}/dbus-1/system-services/org.freedesktop.Accounts.service
%{_datadir}/polkit-1/actions/org.freedesktop.accounts.policy
%dir /var/lib/AccountsService
%dir /var/lib/AccountsService/icons
%dir /var/lib/AccountsService/users

%files libs
%defattr(644,root,root,755)
%attr(755,root,root) %{_libdir}/libaccountsservice.so.*.*.*
%attr(755,root,root) %ghost %{_libdir}/libaccountsservice.so.0
%{_libdir}/girepository-1.0/AccountsService-1.0.typelib

%files devel
%defattr(644,root,root,755)
%attr(755,root,root) %{_libdir}/libaccountsservice.so
%{_includedir}/accountsservice-1.0
%{_pkgconfigdir}/accountsservice.pc
%{_datadir}/dbus-1/interfaces/org.freedesktop.Accounts.User.xml
%{_datadir}/dbus-1/interfaces/org.freedesktop.Accounts.xml
%{_datadir}/gir-1.0/AccountsService-1.0.gir

%if %{with static_libs}
%files static
%defattr(644,root,root,755)
%{_libdir}/libaccountsservice.a
%endif

%files apidocs
%defattr(644,root,root,755)
%{_gtkdocdir}/libaccountsservice
%changelog
* Sat Sep 29 2018 PLD Linux Team <feedback@pld-linux.org>
- For complete changelog see: http://git.pld-linux.org/?p=packages/accountsservice.git;a=log;h=master

* Sat Sep 29 2018 Jakub Bogusz <qboosh@pld-linux.org> f0522f9
- updated to 0.6.54, uses meson now

* Wed Jul 11 2018 Jan Palus <atler@pld-linux.org> 477b0e7
- up to 0.6.50

* Sat May 12 2018 Jan Palus <atler@pld-linux.org> 8e78937
- up to 0.6.49

* Thu Apr 26 2018 Jan Palus <atler@pld-linux.org> ca0fdc5
- up to 0.6.47

* Wed Apr 04 2018 Jan Palus <atler@pld-linux.org> a4cb2d4
- up to 0.6.46

* Thu Mar 22 2018 Jan Palus <atler@pld-linux.org> b1882a4
- package %{_datadir}/accountsservice/interfaces for extensions; rel 2

* Sun Apr 16 2017 Marcin Banasiak <marcin.banasiak@gmail.com> fcc22a2
- Update to 0.6.45

* Wed Oct 05 2016 Jakub Bogusz <qboosh@pld-linux.org> dea2c14
- updated to 0.6.43

* Sat Jun 25 2016 Jakub Bogusz <qboosh@pld-linux.org> 02295a4
- updated to 0.6.42

* Tue Dec 08 2015 Elan Ruusamäe <glen@delfi.ee> 4c7f8ac
- noarch apidocs

* Sun Mar 01 2015 Elan Ruusamäe <glen@delfi.ee> f181f8b
- x32 rebuild
- release 2 (by relup.sh)

* Sat Jan 31 2015 Jakub Bogusz <qboosh@pld-linux.org> d7bb3bf
- updated to 0.6.40

* Sun Dec 28 2014 Jan Rękorajski <baggins@pld-linux.org> 90a0387
- updated gettext BR

* Sun Dec 21 2014 Jakub Bogusz <qboosh@pld-linux.org> 81ef5f4
- updated to 0.9.39
- separated -libs, so daemon is not required for development
- package -apidocs

* Fri Mar 21 2014 Łukasz Kieś <kiesiu@pld-linux.org> 7feb6b9
- updated to 0.6.37

* Sun Oct 20 2013 Łukasz Kieś <kiesiu@pld-linux.org> 74ad9d2
- updated to 0.6.35
- obsoletes Vala bindings

* Tue Jun 25 2013 Łukasz Kieś <kiesiu@pld-linux.org> 846d609
- updated ot 0.6.34

* Thu May 16 2013 Łukasz Kieś <kiesiu@pld-linux.org> 7e39263
- updated to 0.6.32

* Fri Apr 19 2013 Łukasz Kieś <kiesiu@pld-linux.org> 1393c2e
- updated to 0.6.31

* Mon Dec 17 2012 Łukasz Kieś <kiesiu@pld-linux.org> 7ef9ea8
- updated to 0.6.30

